PEP: 160 Title: Python 1.6 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: Fred L. Drake, Jr. <fred@fdrake.net>
Status: Final Type: Informational Content-Type: text/x-rst Created:
25-Jul-2000 Python-Version: 1.6 Post-History:

Introduction
============

This PEP describes the Python 1.6 release schedule. The CVS revision
history of this file contains the definitive historical record.

This release will be produced by BeOpen PythonLabs staff for the
Corporation for National Research Initiatives (CNRI).

Schedule
========

-   August 1: 1.6 beta 1 release (planned).
-   August 3: 1.6 beta 1 release (actual).
-   August 15: 1.6 final release (planned).
-   September 5: 1.6 final release (actual).

Features
========

A number of features are required for Python 1.6 in order to fulfill the
various promises that have been made. The following are required to be
fully operational, documented, and forward compatible with the plans for
Python 2.0:

-   Unicode support: The Unicode object defined for Python 2.0 must be
    provided, including all methods and codec support.

-   SRE: Fredrik Lundh's new regular expression engine will be used to
    provide support for both 8-bit strings and Unicode strings. It must
    pass the regression test used for the pcre-based version of the re
    module.

-   The curses module was in the middle of a transformation to a
    package, so the final form was adopted.

Mechanism
=========

The release will be created as a branch from the development tree rooted
at CNRI's close of business on 16 May 2000. Patches required from more
recent checkins will be merged in by moving the branch tag on individual
files whenever possible in order to reduce mailing list clutter and
avoid divergent and incompatible implementations.

The branch tag is "cnri-16-start".

Patches and features will be merged to the extent required to pass
regression tests in effect on 16 May 2000.

The beta release is tagged "r16b1" in the CVS repository, and the final
Python 1.6 release is tagged "release16" in the repository.

Copyright
=========

This document has been placed in the public domain.

.. Local Variables: mode: indented-text indent-tabs-mode: nil End:
